@@ -39,7 +39,7 @@ class HTTP:
             return result
         else:
             raise PasscodeException
-    async def request_passcode(self, email, password, comp_name):
+    async def request_passcode(self, email, password):
         headers = {}
         headers["User-Agent"] = "KT/3.2.6 Wd/10.0 ko"
         headers["A"] = "win32/3.2.6/kr"
